# !/usr/bin/python
# -*- coding: utf-8 -*-
# @Author:: Arthur Wu
# @Description:: 游客登录，加购促销白名单商品并结算
# @Date:: 2021-05-10 16:30:23
import unittest,allure,time
from configs.globalObj import LOGGER
from YiMao.businessFunc.ClientApiLib import YMClientApi
from YiMao.businessFunc.ServiceApiLib import YMServiceApi
from YiMao.data.WuShangSceneTestData import *


DescName = "007-非会员加购促销白名单商品并结算"
@allure.story(f'[场景测试] {DescName}验证')
class Test_C007(unittest.TestCase):
    f'''@Date:: 2024/11/15
    @Author:: Arthur Wu
    @Desc:: 
    [购物车客户端] {DescName}
    1、武商测试环境，促销白名单商品inputcode为：
    6925303796426
    '''
    def setUp(self) -> None:
        self.timestamp = int(time.time())
        self.ymc = YMClientApi()
        self.yms = YMServiceApi()
        # 促销白名单商品暂未提供
        self.promotional_whitelist_goods = PromotionalWhitelistGoods
        self.market_and_store_info = {
            "MarketId": MarketAndStoreDetails["putMarketId"],
            "StoreId": MarketAndStoreDetails["putStoreId"][0]
        }

    def test_C007_NonVipAddPromotionalWhitelistProducts(self):
        allure.dynamic.description(f"描述：{DescName}")
        allure.step("[前置条件]：先调用管理平台接口，将指定商品添加到促销白名单中")
        pre_respomse = self.yms.add_promotional_product_whitelist(
            self.promotional_whitelist_goods, self.market_and_store_info
        )
        if pre_respomse['data'] is not None:
            LOGGER.info(f"---商品 {self.promotional_whitelist_goods['GoodsInputcode']} "
                        f"已添加到促销白名单中")
            allure.step("[业务步骤]：再调用客户端接口，执行加购操作")
            allure.step("步骤1：session开始")
            self.ymc.session_start()
            allure.step("步骤2：匿名登录")
            Payload01 = {"action": 0, "isAnon": True}
            LoginData = self.ymc.login_app_v2(Payload01)
            allure.step("步骤3：获取白名单商品信息")
            GoodsInfoData1 = self.ymc.get_goods_info(self.promotional_whitelist_goods["GoodsInputcode"])
            if GoodsInfoData1['msg'] != '加购商品不存在':
                allure.step("步骤4：加购白名单商品")
                self.ymc.add_cart_goods(GoodsInfoData1, 1, LoginData)
                allure.step("步骤5：获取购物车商品信息")
                self.ymc.get_cart_goods_info([GoodsInfoData1])
                allure.step("步骤6：请求订单结算")
                self.ymc.request_order_settlement(LoginData)
            else:
                LOGGER.info(f"---商品 {self.promotional_whitelist_goods["GoodsInputcode"]} 不存在")

            allure.step("[后置处理]：删除添加的促销白名单商品")
            self.yms.delete_whitelist_goods()
        else:
            LOGGER.info(f"---添加商品 {self.promotional_whitelist_goods['GoodsInputcode']} "
                        f"到促销白名单失败")


if __name__ == '__main__':
    unittest.main(verbosity=2)